## v0.1.2

- Fixes participant table position (#36)
- Updates README file
- Fixes questionnaire ID page (#38)
- Removes Dockerfile
- Renames studies to new standard

## v0.1.1

- Make command for updating CHANGELOG
- Simplify utils
- Add testing for `api.send_email` locally
- Add client testing for emails


## v0.1.0

- Restructure the routes into modules.
- Add pytest suite to API, utils, and main routes in the app.
- Add coverage analysis to pytest routines.
- Add coverage report to GitHub workflows.
- Add circle plot for appointment status.


